indexia
=======

Collections & connections. A virtual Zettelkasten.

Installation
------------

``pip install indexia``

Visit `indexia.readthedocs.io <https://indexia.readthedocs.io/en/latest/>`_ for 
full documentation.